==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/ColumnResizingSeparatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DefinitionBaseDescriptionMetadata } from "./DefinitionBaseDescriptionMetadata";
import { ColumnResizingSeparatorDescription } from "./ColumnResizingSeparatorDescription";
/**
 * @hidden
 */
var ColumnResizingSeparatorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ColumnResizingSeparatorDescriptionMetadata, _super);
    function ColumnResizingSeparatorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ColumnResizingSeparatorDescriptionMetadata.b = function (a) {
        if (ColumnResizingSeparatorDescriptionMetadata.a == null) {
            ColumnResizingSeparatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ColumnResizingSeparatorDescriptionMetadata.c(ColumnResizingSeparatorDescriptionMetadata.a);
        }
        if (a.g(ColumnResizingSeparatorDescriptionMetadata.a)) {
            return;
        }
        a.s(ColumnResizingSeparatorDescriptionMetadata.a);
    };
    ColumnResizingSeparatorDescriptionMetadata.c = function (a) {
        DefinitionBaseDescriptionMetadata.c(a);
        a.item("ActualOpacity", "Number:double");
        a.item("Opacity", "Number:double");
    };
    ColumnResizingSeparatorDescriptionMetadata.d = function (a) {
        ColumnResizingSeparatorDescriptionMetadata.b(a);
        a.u("ColumnResizingSeparator", function () { return new ColumnResizingSeparatorDescription(); });
        a.t("ColumnResizingSeparator", ColumnResizingSeparatorDescriptionMetadata.a);
    };
    ColumnResizingSeparatorDescriptionMetadata.$t = markType(ColumnResizingSeparatorDescriptionMetadata, 'ColumnResizingSeparatorDescriptionMetadata');
    ColumnResizingSeparatorDescriptionMetadata.a = null;
    return ColumnResizingSeparatorDescriptionMetadata;
}(Base));
export { ColumnResizingSeparatorDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/ColumnResizingSeparatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DefinitionBaseDescriptionMetadata } from "./DefinitionBaseDescriptionMetadata";
import { ColumnResizingSeparatorDescription } from "./ColumnResizingSeparatorDescription";
/**
 * @hidden
 */
var ColumnResizingSeparatorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ColumnResizingSeparatorDescriptionMetadata, _super);
    function ColumnResizingSeparatorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ColumnResizingSeparatorDescriptionMetadata.b = function (a) {
        if (ColumnResizingSeparatorDescriptionMetadata.a == null) {
            ColumnResizingSeparatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ColumnResizingSeparatorDescriptionMetadata.c(ColumnResizingSeparatorDescriptionMetadata.a);
        }
        if (a.j(ColumnResizingSeparatorDescriptionMetadata.a)) {
            return;
        }
        a.y(ColumnResizingSeparatorDescriptionMetadata.a);
    };
    ColumnResizingSeparatorDescriptionMetadata.c = function (a) {
        DefinitionBaseDescriptionMetadata.c(a);
        a.item("ActualOpacity", "Number:double");
        a.item("Opacity", "Number:double");
    };
    ColumnResizingSeparatorDescriptionMetadata.d = function (a) {
        ColumnResizingSeparatorDescriptionMetadata.b(a);
        a.aa("ColumnResizingSeparator", function () { return new ColumnResizingSeparatorDescription(); });
        a.z("ColumnResizingSeparator", ColumnResizingSeparatorDescriptionMetadata.a);
    };
    ColumnResizingSeparatorDescriptionMetadata.$t = markType(ColumnResizingSeparatorDescriptionMetadata, 'ColumnResizingSeparatorDescriptionMetadata');
    ColumnResizingSeparatorDescriptionMetadata.a = null;
    return ColumnResizingSeparatorDescriptionMetadata;
}(Base));
export { ColumnResizingSeparatorDescriptionMetadata };
